@@ -23,9 +23,5 @@ class CutefishProfile(XorgProfile):
 	def default_greeter_type(self) -> Optional[GreeterType]:
 		return GreeterType.Sddm
 
-	def preview_text(self) -> Optional[str]:
-		text = str(_('Environment type: {}')).format(self.profile_type.value)
-		return text + '\n' + self.packages_text()
-
 	def install(self, install_session: 'Installer'):
 		super().install(install_session)
